@@ -35,7 +35,6 @@
 
 class ShowImageDialog;
 class SaveLocation;
-class KAboutData;
 class QProgressBar;
 
 using namespace KSaneIface;
@@ -46,7 +45,6 @@ class Skanlite : public QDialog
 
 public:
     explicit Skanlite(const QString &device, QWidget *parent);
-    void setAboutData(KAboutData *aboutData);
 
 private:
     // Order of items in save mode combo-box
@@ -56,14 +54,13 @@ private:
     };
 
     void readSettings();
-    void doSaveImage(bool askFilename = true);
     void loadScannerOptions();
 
     void processSelectionOptions(QMap<QString, QString> &opts, bool ignoreSelection);
 
 private Q_SLOTS:
     void showSettingsDialog();
-    void imageReady(QByteArray &, int, int, int, int);
+    void imageReady(const QImage &image);
     void saveImage();
     void updateSaveProgress();
     void imageSaved(const QUrl &url, const QString &name, bool success);
@@ -95,7 +92,6 @@ protected:
     void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;
 
 private:
-    KAboutData              *m_aboutData;
     KSaneWidget             *m_ksanew = nullptr;
     QProgressBar            *m_saveProgressBar = nullptr;
     QUrl                     m_currentSaveUrl;
@@ -108,11 +104,6 @@ private:
     QMap<QString, QString>   m_defaultScanOpts;
     QMap<QString, QString>   m_pendingApplyScanOpts;
     QImage                   m_img;
-    QByteArray               m_data;
-    int                      m_width;
-    int                      m_height;
-    int                      m_bytesPerLine;
-    int                      m_format;
 
     DBusInterface            m_dbusInterface;
     QStringList              m_filterList;
